Pcf8563LowLevel

Struct Pcf8563LowLevel 

pub struct Pcf8563LowLevel<I> { /* private fields */ }
Root block of the Pcf8563LowLevel driver

Implementations

Source

impl<I> Pcf8563LowLevel<I>

pub const fn new(interface: I) -> Self

Create a new instance of the block based on device interface

pub fn read_all_registers( &mut self, callback: impl FnMut(u8, &'static str, FieldSetValue), ) -> Result<(), I::Error>
where I: RegisterInterface<AddressType = u8>,

Read all readable register values in this block from the device. The callback is called for each of them. Any registers in child blocks are not included.

The callback has three arguments:

  • The address of the register
  • The name of the register (with index for repeated registers)
  • The read value from the register

This is useful for e.g. debug printing all values. The given field_sets::FieldSetValue has a Debug and Format implementation that forwards to the concrete type the lies within so it can be printed without matching on it.

pub async fn read_all_registers_async( &mut self, callback: impl FnMut(u8, &'static str, FieldSetValue), ) -> Result<(), I::Error>
where I: AsyncRegisterInterface<AddressType = u8>,

Read all readable register values in this block from the device. The callback is called for each of them. Any registers in child blocks are not included.

The callback has three arguments:

  • The address of the register
  • The name of the register (with index for repeated registers)
  • The read value from the register

This is useful for e.g. debug printing all values. The given field_sets::FieldSetValue has a Debug and Format implementation that forwards to the concrete type the lies within so it can be printed without matching on it.

pub fn control_status_1( &mut self, ) -> RegisterOperation<'_, I, u8, ControlStatus1, RW>

Control and status register 1. Controls clock operation, test modes, and power-on reset override.

pub fn control_status_2( &mut self, ) -> RegisterOperation<'_, I, u8, ControlStatus2, RW>

Control and status register 2. Controls timer/alarm interrupts and flags.

pub fn seconds(&mut self) -> RegisterOperation<'_, I, u8, Seconds, RW>

Seconds register with voltage-low flag. Seconds are BCD encoded (0-59).

pub fn minutes(&mut self) -> RegisterOperation<'_, I, u8, Minutes, RW>

Minutes register. Minutes are BCD encoded (0-59).

pub fn hours(&mut self) -> RegisterOperation<'_, I, u8, Hours, RW>

Hours register. Hours are BCD encoded (0-23, 24-hour format).

pub fn days(&mut self) -> RegisterOperation<'_, I, u8, Days, RW>

Days register. Days are BCD encoded (1-31).

pub fn weekdays(&mut self) -> RegisterOperation<'_, I, u8, Weekdays, RW>

Weekdays register. Weekday value (0-6, user-definable assignment).

pub fn century_months( &mut self, ) -> RegisterOperation<'_, I, u8, CenturyMonths, RW>

Century flag and months register. Months are BCD encoded (1-12).

pub fn years(&mut self) -> RegisterOperation<'_, I, u8, Years, RW>

Years register. Years are BCD encoded (0-99).

pub fn minute_alarm(&mut self) -> RegisterOperation<'_, I, u8, MinuteAlarm, RW>

Minute alarm register. Minutes are BCD encoded (0-59).

pub fn hour_alarm(&mut self) -> RegisterOperation<'_, I, u8, HourAlarm, RW>

Hour alarm register. Hours are BCD encoded (0-23).

pub fn day_alarm(&mut self) -> RegisterOperation<'_, I, u8, DayAlarm, RW>

Day alarm register. Days are BCD encoded (1-31).

pub fn weekday_alarm( &mut self, ) -> RegisterOperation<'_, I, u8, WeekdayAlarm, RW>

Weekday alarm register.

pub fn clkout_control( &mut self, ) -> RegisterOperation<'_, I, u8, ClkoutControl, RW>

CLKOUT frequency control register.

pub fn timer_control( &mut self, ) -> RegisterOperation<'_, I, u8, TimerControl, RW>

Timer control register.

pub fn timer(&mut self) -> RegisterOperation<'_, I, u8, Timer, RW>

Timer countdown value register. 8-bit binary countdown timer (0-255). Countdown period = n / source_clock_frequency When read, returns current countdown value.